@@ -1,4 +1,6 @@
 package Parley::Contributors;
+use strict;
+use Parley::Version;  our $VERSION = $Parley::VERSION;
 
 # this is a dummy package to provide POD
 
@@ -22,14 +24,24 @@ Chisel Wright C<< <chiselwright@users.berlios.de> >>
 
 L<FamFamFam Silk Icons|http://www.famfamfam.com/lab/icons/silk/>
 
+L<FamFamFam Flag Icons|http://www.famfamfam.com/lab/icons/flags/>
+
 =head1 I18N
 
+=head2 Dutch
+
+Translation by Rob Partridge
+
+Additional translations by Kevin Golding
+
 =head2 Italian
 
 Translation by Darius Jokilehto
 
 =head1 PATCHES AND BUG-FIXES
 
+Toby Corkindale C<< TJC >>
+
 Kaare Rasmussen C<< CPANID: KAARE >>
 
 =head1 PROJECTS
