@@ -2,6 +2,8 @@ package Parley::Controller::Terms;
 # vim: ts=8 sts=4 et sw=4 sr sta
 use strict;
 use warnings;
+
+use Parley::Version;  our $VERSION = $Parley::VERSION;
 use base 'Catalyst::Controller';
 
 use Parley::App::Terms qw( :terms );
@@ -26,7 +28,7 @@ sub index : Private {
         $c->model('ParleyDB')->resultset('Terms')->search(
             {},
             {
-                'order_by' => 'created DESC',
+                'order_by' => [\'created DESC'],
             }
         )
     ;
