@@ -3,6 +3,8 @@ package Parley::ResultSet::Thread;
 use strict;
 use warnings;
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+
 use base 'DBIx::Class::ResultSet';
 
 # This is slightly complicated; the way we find the last post a user has seen
@@ -46,7 +48,7 @@ sub last_post_viewed_in_thread {
             },
             {
                 rows        => 1,
-                order_by    => 'created ASC',
+                order_by    => [\'created ASC'],
             }
         );
 
@@ -73,7 +75,7 @@ sub last_post_viewed_in_thread {
             },
             {
                 rows        => 1,
-                order_by    => 'created DESC',
+                order_by    => [\'created DESC'],
             }
         );
 
@@ -113,18 +115,38 @@ sub recent {
         $where,
         {
             join        => \@join,
-            order_by    => 'last_post.created DESC',
+            order_by    => [\'last_post.created DESC'],
 
             rows        => $c->config->{threads_per_page},
             page        => $c->stash->{current_page},
 
             prefetch => [
                 {'creator' => 'authentication'},
-                'last_post',
+                {'last_post' => 'creator'},
                 'forum',
             ],
         }
     );
 }
 
+sub record_from_id {
+    my ($resultsource, $thread_id) = @_;
+    my ($rs);
+
+    $rs = $resultsource->find(
+        {
+            'me.id'  => $thread_id,
+        },
+        {
+            prefetch => [
+                { 'forum' => 'last_post' },
+                'creator',
+                'last_post',
+            ]
+        }
+    );
+
+    return $rs;
+}
+
 1;
