@@ -4,9 +4,13 @@ use strict;
 use warnings;
 use base 'DBIx::Class';
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+
 __PACKAGE__->load_components('PK::Auto', 'Core');
-__PACKAGE__->table('forum_moderator');
+__PACKAGE__->table('parley.forum_moderator');
 __PACKAGE__->add_columns(
+    id => {},
+
     person_id => {
         data_type       => "integer",
         default_value   => undef,
@@ -29,6 +33,8 @@ __PACKAGE__->add_columns(
     },
 );
 
+__PACKAGE__->set_primary_key(qw/id/);
+
 __PACKAGE__->add_unique_constraint(
     'forum_moderator_person_key',
     ['person_id', 'forum_id']
