@@ -3,8 +3,10 @@ use strict;
 use warnings;
 use base 'DBIx::Class';
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+
 __PACKAGE__->load_components("PK::Auto", "Core");
-__PACKAGE__->table("preference_time_string");
+__PACKAGE__->table("parley.preference_time_string");
 __PACKAGE__->add_columns(
     id => {
         data_type => "integer",
