@@ -5,10 +5,12 @@ package Parley::Schema::RegistrationAuthentication;
 use strict;
 use warnings;
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+
 use base 'DBIx::Class';
 
 __PACKAGE__->load_components("PK::Auto", "Core");
-__PACKAGE__->table("registration_authentication");
+__PACKAGE__->table("parley.registration_authentication");
 __PACKAGE__->add_columns(
   "id" => {
     data_type => "text",
