@@ -9,7 +9,7 @@ use DateTime::Format::Pg;
 use Parley::Version;  our $VERSION = $Parley::VERSION;
 
 __PACKAGE__->load_components('PK::Auto', 'Core');
-__PACKAGE__->table('terms');
+__PACKAGE__->table('parley.terms');
 
 __PACKAGE__->add_columns(
     id => {
