@@ -8,7 +8,7 @@ use Parley::Version;  our $VERSION = $Parley::VERSION;
 use base 'DBIx::Class';
 
 __PACKAGE__->load_components('PK::Auto', 'Core');
-__PACKAGE__->table('terms_agreed');
+__PACKAGE__->table('parley.terms_agreed');
 
 __PACKAGE__->add_columns(
     id => {
