@@ -5,13 +5,15 @@ package Parley::Schema::ThreadView;
 use strict;
 use warnings;
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+
 use base 'DBIx::Class';
 use DateTime::Format::Pg;
 
 use Parley::App::DateTime qw( :interval );
 
 __PACKAGE__->load_components("PK::Auto", "Core");
-__PACKAGE__->table("thread_view");
+__PACKAGE__->table("parley.thread_view");
 __PACKAGE__->add_columns(
   "id" => {
     data_type => "integer",
