@@ -1,6 +1,7 @@
 package Parley::View::TT;
-
+# vim: ts=8 sts=4 et sw=4 sr sta
 use strict;
+use warnings;
 
 use Parley::Version;  our $VERSION = $Parley::VERSION;
 use base 'Catalyst::View::TT';
